@@ -7,7 +7,7 @@ use strict;
 use utf8;
 use warnings 'all';
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 use 5.008;
 use File::Spec;
@@ -90,7 +90,7 @@ sub file_encoding_ok {
 
                 my @type = qw(0 0 0);
                 ++$type[_detect_utf8(\$_)];
-                my ($latin1, $ascii, $utf8) = @type;
+                my ($latin1, $utf8) = @type[0, 2];
 
                 if (/^use\s+utf8$/) {
                     $use_utf8 = 1;
@@ -114,7 +114,7 @@ sub file_encoding_ok {
             # POD
             my @type = qw(0 0 0);
             ++$type[_detect_utf8(\$line)];
-            my ($latin1, $ascii, $utf8) = @type;
+            my ($latin1, $utf8) = @type[0, 2];
 
             if (($pod_utf8 == 0) && $utf8) {
                 $Test->ok(0, $name);
@@ -266,43 +266,27 @@ sub _detect_utf8 {
 __END__
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Test::Mojibake - check your source for encoding misbehavior.
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
-L<Test::Mojibake> lets you check for inconsistencies in source/documentation encoding, and report its results in standard L<Test::Simple> fashion.
+    # Test::Mojibake lets you check for inconsistencies in source/documentation encoding, and report its results in standard Test::Simple fashion.
 
-    use Test::Mojibake tests => $num_tests;
+    use Test::Mojibake;
     file_encoding_ok($file, 'Valid encoding');
-
-Module authors can include the following in a F<t/mojibake.t> file and have L<Test::Mojibake> automatically find and check all source files in a module distribution:
-
-    #!perl -T
-    use strict;
-
-    BEGIN {
-        unless ($ENV{RELEASE_TESTING}) {
-            require Test::More;
-            Test::More::plan(skip_all => 'these tests are for release candidate testing');
-        }
-    }
-
-    use Test::More;
-
-    eval 'use Test::Mojibake';
-    plan skip_all => 'Test::Mojibake required for source encoding testing' if $@;
-
-    all_files_encoding_ok();
+    done_testing($num_tests);
 
 =head1 DESCRIPTION
 
-Many modern text editors automatically save files using UTF-8 codification, however, L<perl> interpreter does not expects it I<by default>. Whereas this does not represent a big deal on (most) backend-oriented programs, Web framework (L<Catalyst>, L<Mojolicious>) based applications will suffer of so-called L<Mojibake|http://en.wikipedia.org/wiki/Mojibake> (lit. "unintelligible sequence of characters").
+Many modern text editors automatically save files using UTF-8 codification, however, L<perl> interpreter does not expects it I<by default>. Whereas this does not represent a big deal on (most) backend-oriented programs, Web framework (L<Catalyst|http://www.catalystframework.org/>, L<Mojolicious|http://mojolicio.us/>) based applications will suffer of so-called L<Mojibake|http://en.wikipedia.org/wiki/Mojibake> (lit. "unintelligible sequence of characters").
 
 Even worse: if an editor saves BOM (Byte Order Mark, C<U+FEFF> character in Unicode) at the start of the script with executable bit set (on Unix systems), it won't execute at all, due to shebang corruption.
 
@@ -344,10 +328,9 @@ The optional second argument C<TESTNAME> is the name of the test.  If it is omit
 
 =head2 all_files_encoding_ok( [@entries] )
 
-Validates codification of all the files under C<@entries>. It runs L<all_files()> on directories and assumes everything else to be a file to be tested. It calls the C<plan()> function for you (one test for each file), so you can't have already called C<plan>.
+Validates codification of all the files under C<@entries>. It runs C<all_files()> on directories and assumes everything else to be a file to be tested. It calls the C<plan()> function for you (one test for each file), so you can't have already called C<plan>.
 
-If C<@entries> is empty or not passed, the function finds all source/documentation files in files in the F<blib> directory if it exists, or the F<lib> directory if not. A source/documentation file is one that ends with F<.pod>, F<.pl> and F<.pm>, or any file where
-the first line looks like a shebang line.
+If C<@entries> is empty or not passed, the function finds all source/documentation files in files in the F<blib> directory if it exists, or the F<lib> directory if not. A source/documentation file is one that ends with F<.pod>, F<.pl> and F<.pm>, or any file where the first line looks like a shebang line.
 
 =head2 all_files( [@dirs] )
 
@@ -371,8 +354,7 @@ Any file that ends in F<.bat> and has a first line with C<"--*-Perl-*--"> on it.
 
 =back
 
-The order of the files returned is machine-dependent.  If you want them
-sorted, you'll have to sort them yourself.
+The order of the files returned is machine-dependent.  If you want them sorted, you'll have to sort them yourself.
 
 =head2 _detect_utf8( \$string )
 
@@ -398,7 +380,28 @@ Return codes:
 
 L<Unicode::CheckUTF8> is highly recommended, however, it is optional and this function will fallback to the Pure Perl implementation of the following PHP code: L<http://www.php.net/manual/en/function.utf8-encode.php#85293>
 
-=encoding utf8
+=for test_synopsis my ($file, $num_tests);
+
+=head1 SAMPLE TEST SCRIPT
+
+Module authors can include the following in a F<t/mojibake.t> file and have L<Test::Mojibake> automatically find and check all source files in a module distribution:
+
+    #!perl -T
+    use strict;
+
+    BEGIN {
+        unless ($ENV{RELEASE_TESTING}) {
+            require Test::More;
+            Test::More::plan(skip_all => 'these tests are for release candidate testing');
+        }
+    }
+
+    use Test::More;
+
+    eval 'use Test::Mojibake';
+    plan skip_all => 'Test::Mojibake required for source encoding testing' if $@;
+
+    all_files_encoding_ok();
 
 =head1 OPERATION
 
